bet.sampling package
====================

Submodules
----------

bet.sampling.LpGeneralizedSamples module
----------------------------------------

.. automodule:: bet.sampling.LpGeneralizedSamples
    :members:
    :undoc-members:
    :show-inheritance:

bet.sampling.basicSampling module
---------------------------------

.. automodule:: bet.sampling.basicSampling
    :members:
    :undoc-members:
    :show-inheritance:

bet.sampling.useLUQ module
--------------------------

.. automodule:: bet.sampling.useLUQ
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bet.sampling
    :members:
    :undoc-members:
    :show-inheritance:
